<template>
  <!-- 扩展信息弹窗 -->
  <div>
    <el-dialog
      title="设备扩展信息"
      :visible.sync="showExtend"
      :before-close="handleClose"
      custom-class="bbsl-location-dialog"
      width="80%" :close-on-click-modal="false"
    >
      <div class="bbsl-common-page">
        <div class="bbsl-table-search">
          <el-form v-model="queryParam" :inline="true">
            <el-row :gutter="10">
              <el-col :span="6">
                <el-form-item label="属性名称">
                  <el-input
                    maxlength="64"
                    placeholder="请输入属性名称"
                    clearable
                    v-model="querys[1].value"
                  ></el-input>
                </el-form-item>
              </el-col>
              <el-col :span="6">
                <el-form-item label="控件类型">
                  <el-select
                    v-model="querys[2].value"
                    clearable
                    placeholder="请选择控件类型"
                  >
                    <el-option
                      v-for="item in kjlxList"
                      :key="item.value"
                      :label="item.name"
                      :value="item.value"
                    ></el-option>
                  </el-select>
                </el-form-item>
              </el-col>
              <el-col :span="6">
                <el-form-item>
                  <el-button
                    type="primary"
                    icon="el-icon-search"
                    @click="handleSearch"
                  >搜索
                  </el-button
                  >
                  <el-button icon="el-icon-refresh" @click="handleReset"
                  >重置
                  </el-button
                  >
                </el-form-item>
              </el-col>
            </el-row>
          </el-form>
        </div>
        <div class="bbsl-table-content" ref="contentPanel">
          <div class="bbsl-btn-content" ref="btnPanel">
            <el-button icon="el-icon-plus" type="primary" @click="handleAdd"
            >新增
            </el-button
            >
            <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
              <el-button
                slot="reference"
                :disabled="!multipleSelection.length"
                icon="el-icon-delete"
                style="margin-left: 10px"
              >删除
              </el-button
              >
            </el-popconfirm>
            <el-button
              style="margin-left: 10px"
              icon="el-icon-sort"
              @click="savePropertyf"
            >保存排序号
            </el-button
            >
          </div>
          <el-table
            border
            size="mini"
            v-loading="loading"
            ref="multipleSelection"
            :data="tableData"
            :style="{width: '100%'}"
            :max-height="tableMaxHeight"
            :cell-style="{'text-align': 'center'}"
            :header-cell-style="{'text-align': 'center'}"
            @row-dblclick="handleDbClick"
            @selection-change="handleSelectionChange"
          >
            <el-table-column type="selection" width="55"></el-table-column>
            <el-table-column
              fixed
              type="index"
              width="55"
              label="序号"
            ></el-table-column>
            <el-table-column
              sortable
              prop="code"
              label="属性编码"
              show-overflow-tooltip
            ></el-table-column>
            <el-table-column
              sortable
              prop="name"
              label="属性名称"
              show-overflow-tooltip
            ></el-table-column>
            <el-table-column
              sortable
              prop="ctlTypeName"
              label="控件类型"
              show-overflow-tooltip
            ></el-table-column>
            <el-table-column
              sortable
              prop="isRequired"
              label="是否必填"
              show-overflow-tooltip
            >
              <template slot-scope="scope">
                {{
                scope.row.isRequired == 0
                ? '否'
                : scope.row.isRequired == 1
                ? '是'
                : ''
                }}
              </template>
            </el-table-column>
            <el-table-column
              sortable
              prop="layout"
              label="布局"
              show-overflow-tooltip
            ></el-table-column>
            <el-table-column
              sortable
              prop="sn"
              label="排序"
              show-overflow-tooltip
            >
              <template slot-scope="scope">
                <el-input
                  type="number"
                  size="small"
                  min="1"
                  @input="insort(scope.row)"
                  v-model="scope.row.sn"
                >
                </el-input>
              </template>
            </el-table-column>
          </el-table>
          <el-pagination
            align="right"
            background
            class="bbsl-pagination"
            ref="paginationPanel"
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="queryParam.pageBean.page"
            :page-sizes="[20, 30, 40, 50]"
            :page-size="queryParam.pageBean.pageSize"
            layout="total, sizes, prev, pager, next, jumper"
            :total="total"
          ></el-pagination>
        </div>
        <EquipmentExtendInfoDialog ref="formModal"></EquipmentExtendInfoDialog>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import EquipmentExtendInfoDialog from '@/views/Device/deviceManage/components/EquipmentExtendInfoDialog'
import resourceManage from '@/api/device/resourceManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'EquipmentExtendDialog',
  components: {
    EquipmentExtendInfoDialog
  },
  mixins: [TableMixin],
  props: {
    showExtend: {
      type: Boolean,
      default: false
    },
    parameter: {
      type: Object,
      default: function() {
      }
    }
  },
  data() {
    return {
      visible: false,
      url: {
        delete: '/device/params/conf/'
      },
      params: {
        ctlType: null
      },
      sortList: {},
      kjlxList: [],
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceId',
          relation: 'AND',
          value: this.parameter.id
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'ctlType',
          relation: 'AND',
          value: ''
        }
      ]
    }
  },
  created() {
    this.kjlxList = dictUtils.getDictItemsFromCache('kjlx')
  },
  mounted() {
  },
  methods: {
    clearQuerys() {
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    insort(val) {
      let id = val.id
      let value = val.sn
      this.sortList[id] = value
    },
    savePropertyf() {
      resourceManage.saveProperty(this.sortList, (res) => {
        if (res.state) {
          this.$notify({
            type: 'success',
            message: res.message,
            duration: 2000
          })
          this.loadData()
        } else {
          this.$message.warning(res.message)
        }
      })
    },
    handleAdd() {
      this.$refs.formModal.add(this.parameter)
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      resourceManage.loadExtend(this.queryParam, (res) => {
        res.rows.sort((a, b) => {
          return a.sn - b.sn
        })
        this.tableData = res.rows
        this.total = res.total
        if (this.tableData.length > 0) {
          this.tableData.forEach((e) => {
            if (e.ctlType) {
              this.kjlxList.forEach((k) => {
                if (e.ctlType == k.value) {
                  e.ctlTypeName = k.name
                }
              })
            }
          })
        }
        this.$set(this.tableData)
        this.loading = false
      })
    },
    handleClose() {
      this.visible = false
      this.$emit('closeExtend')
      this.$emit('reload')
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

::v-deep .el-dialog {
  margin: 10vh auto !important;
}

::v-deep .el-dialog__body {
  height: 70vh;
}

.bbsl-table-search {
  box-shadow: 0px 0px 0 0;
}

::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
}
</style>
